@@ -1,17 +1,13 @@
 #include <stdio.h>
-#include <string.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <signal.h>
 #include <fam.h>
 #include <errno.h>
 #include <error.h>
-#include <sys/stat.h>
 #include "config.h"
 #include "gettext.h"
 #include "fileschanged.h"
 #include "opts.h"
-#include "node.h"
 #include "list.h"
 #include "monitor.h"
 #include "filelist.h"
@@ -38,7 +34,8 @@ fileschanged_main (FAMConnection *c, void *list)
   while (1)
     {
       monitor_handle_events (c, list, 0, -1);
-      if ((arguments.fileschanged.filechangetimeout > 0) && (arguments.fileschanged.showchanged))
+      if ((arguments.fileschanged.filechangetimeout > 0) && 
+	  (arguments.fileschanged.showchanged))
 	{
 	  wl_show_changed_files (arguments.fileschanged.filechangetimeout, 
 				 show_changed_file);
@@ -60,7 +57,7 @@ fileschanged_cleanup ()
   return;
 }
 
-void 
+static void 
 sigHandler (int sig)
 {
   if (( sig == SIGINT ) || (sig == SIGPIPE))
@@ -83,9 +80,10 @@ init_locales (const char *name)
 }
 
 int 
-main(int argc, char **argv)
+main (int argc, char **argv)
 {
   int retval;
+  unsigned int count = 0;
 
   if (init_locales (PACKAGE_NAME))
     error(1, 0, "Error: Couldn't set locale");
@@ -104,6 +102,11 @@ main(int argc, char **argv)
   //either from file, stdin, or from command line.
   filelist_populate (app.list_of_files_to_monitor);
 
+  //bail if there's nothing to do
+  list_count (app.list_of_files_to_monitor, &count);
+  if (count == 0)
+    error(1, 0, _("Error: No files to monitor."));
+
   setlinebuf (stdout);
 
   fileschanged_main (&app.c, app.list_of_files_to_monitor);
@@ -111,6 +114,5 @@ main(int argc, char **argv)
 
   fileschanged_cleanup ();
 
-  exit(0);
+  exit (0);
 }
-
