@@ -7,4 +7,10 @@ struct fileschanged_appstate_t
 	FAMConnection c;
 	void *list_of_files_to_monitor;
 };
+
+/* For environments not already using gamin */
+#ifndef HAVE_FAMNOEXISTS
+#define FAMNoExists(X) ;
+#endif
+
 #endif
