@@ -1,8 +1,8 @@
 #define _GNU_SOURCE
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <signal.h>
+#include <string.h>
 #include "handlers.h"
 #include "list.h"
 #include "node.h"
@@ -10,6 +10,37 @@
 #include "wl.h"
 extern struct arguments_t arguments;
 
+/*
+ * handlers.c
+ *
+ * Handle one file notification event from the FAM server.  We need to decide
+ * what we're going to do with this event, and we do something different based
+ * on what the event is.  Based on the event, we'll call one of the function
+ * pointers in `handlers', and each one of those eventually call `show_event'.
+ *
+ * handle_event needs to know your FAMConnection, the LIST of files that we're
+ * monitoring, E is the event from the FAM server, and TIME_OF_EVENT is just a
+ * timestamp.
+ *
+ * We need to pass down the LIST because we might have to add more files to
+ * it, depending on if a new directory was created in a directory we're
+ * already monitoring recursively.
+ *
+ *   handle_event(FAMConnection *c, void *list, FAMEvent *e, 
+ *     time_t time_of_event);
+ *
+ * There's one case where we need to show events outside of handlers.  It is
+ * when we're waiting for a bunch of created/changed events to pass before
+ * stating that the file has created/changed (see the -t option).  That is why
+ * this function is exported.  This call is in:
+ * fileschanged.c:fileschanged_main().
+ *
+ *   show_event(enum handler_enum_t id, char *filename);
+ *
+ * Note: it's important to know how determine_handler() works and why.  If
+ * there's a critical function to fileschanged, that is it.
+ *
+ */
 //private prototypes
 static int handle_created_file (FAMConnection *c, void *list, enum handler_enum_t id, char *filename);
 static int handle_created_dir (FAMConnection *c, void *list, enum handler_enum_t id, char *filename);
@@ -19,6 +50,7 @@ static int handle_deleted_file (FAMConnection *c, void *list, enum handler_enum_
 static int handle_deleted_dir (FAMConnection *c, void *list, enum handler_enum_t id, char *filename);
 static int handle_startexecuting_file (FAMConnection *c, void *list, enum handler_enum_t id, char *filename);
 static int handle_stopexecuting_file (FAMConnection *c, void *list, enum handler_enum_t id, char *filename);
+
 static struct handler_t handlers[FC_HANDLER_MAX]=
 {
     { FC_CREATED_FILE, "A", handle_created_file },
@@ -27,10 +59,8 @@ static struct handler_t handlers[FC_HANDLER_MAX]=
     { FC_CHANGED_DIR, "M", handle_changed_dir },
     { FC_DELETED_FILE, "R", handle_deleted_file },
     { FC_DELETED_DIR, "R", handle_deleted_dir },
-    { FC_STARTEXECUTING_FILE, "E", 
-      handle_startexecuting_file },
-    { FC_STOPEXECUTING_FILE, "X", 
-      handle_stopexecuting_file },
+    { FC_STARTEXECUTING_FILE, "E", handle_startexecuting_file },
+    { FC_STOPEXECUTING_FILE, "X", handle_stopexecuting_file },
 };
 
 static void 
@@ -74,14 +104,16 @@ determine_handler (void *list, FAMEvent *e, enum handler_enum_t *id, char **file
   *id = FC_HANDLER_MAX;
   //lookup the node that the event corresponds to.
   filenode = (struct node_t *)e->userdata;
-  if (S_ISREG(filenode->statbuf.st_mode))
+  if (S_ISREG (filenode->statbuf.st_mode))
     {
       //the simple case.
       //okay it's a file we were monitoring to get this event.
       *filename = strdup (filenode->filename);
+      if (!*filename)
+	return -2;
       set_id_for_file (e, id);
     }
-  else if (S_ISDIR(filenode->statbuf.st_mode))
+  else if (S_ISDIR (filenode->statbuf.st_mode))
     {
       //okay it's a directory we were monitoring to get this event.
       //it could still be a file in the directory we are monitoring.
@@ -89,6 +121,8 @@ determine_handler (void *list, FAMEvent *e, enum handler_enum_t *id, char **file
       if (e->filename[0] == '/') //it's a directory
 	{
 	  *filename = strdup (filenode->filename);
+	  if (!*filename)
+	    return -3;
 	  set_id_for_dir (e, id);
 	}
       else
@@ -102,12 +136,14 @@ determine_handler (void *list, FAMEvent *e, enum handler_enum_t *id, char **file
 	      char *newfilename = NULL;
 	      struct node_t newnode;
 	      int retval;
-	      asprintf (&newfilename, "%s/%s", filenode->filename, e->filename);
+	      if (asprintf (&newfilename, "%s/%s", filenode->filename, 
+			    e->filename) == -1)
+		return -4;
 	      retval = node_new (&newnode, newfilename);
 	      free (newfilename); newfilename = NULL;
 	      if (retval == 0)
 		{
-		  isdir = S_ISDIR(newnode.statbuf.st_mode);
+		  isdir = S_ISDIR (newnode.statbuf.st_mode);
 		  *filename = strdup (newnode.filename);
 		  node_free (&newnode);
 		}
@@ -120,7 +156,9 @@ determine_handler (void *list, FAMEvent *e, enum handler_enum_t *id, char **file
 	    }
 	  else
 	    {
-	      asprintf (filename, "%s/%s", filenode->filename, e->filename);
+	      if (asprintf (filename, "%s/%s", filenode->filename, 
+			    e->filename) == -1)
+		return -3;
 	      //it's a deleted file or directory.  how can we tell it's type?  it's gone now.
 	      //if it were a directory we were monitoring, and we were in recursive mode,
 	      //then we would have received a notification for that directory with an absolute name.
@@ -224,7 +262,7 @@ handle_created_dir(FAMConnection *c, void *list, enum handler_enum_t id, char *f
 	  //printf("Adding '%s'\n",filename);
 	  list_add (list, &newdir);
 	  list_count (list, &count);
-	  list_get_element (list,count - 1, &node);
+	  list_get_element (list, count - 1, &node);
 	  FAMMonitorDirectory (c, newdir.filename, &newdir.request, 
 			       (void*)node);
 	  node_free (&newdir);
@@ -232,12 +270,10 @@ handle_created_dir(FAMConnection *c, void *list, enum handler_enum_t id, char *f
       else if (retval < 0)
 	return -1;
     }
-  else
+
+  if (arguments.fileschanged.showcreated)
     {
-      if (arguments.fileschanged.showcreated)
-	{
-	  show_event (id, filename);
-	}
+      show_event (id, filename);
     }
 
   return 0;
