@@ -3,13 +3,10 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
 #include <dirent.h>
 #include "listdirs.h"
 #include "list.h"
 #include "xrealpath.h"
-static int _listdirs (struct node_t *dir, void *dirs, void *ancestors);
 
 static int 
 _listdirs (struct node_t *dir, void *dirs, void *ancestors)
@@ -34,12 +31,13 @@ _listdirs (struct node_t *dir, void *dirs, void *ancestors)
 	continue;
       if (strcmp (namelist[i]->d_name, "..") == 0)
 	continue;
-      asprintf (&d, "%s/%s", dir->filename, namelist[i]->d_name);
+      if (asprintf (&d, "%s/%s", dir->filename, namelist[i]->d_name) == -1)
+	return -1;
       retval = node_new (&newdir, d);
       free (d); d = NULL;
       if (retval == 0)
 	{
-	  if (S_ISDIR(newdir.statbuf.st_mode))
+	  if (S_ISDIR (newdir.statbuf.st_mode))
 	    retval = _listdirs (&newdir, dirs,ancestors);
 	  node_free (&newdir);
 	}
