@@ -1,7 +1,6 @@
 #include <argp.h>
 #include <stdlib.h>
 #include <string.h>
-#include <dlfcn.h>
 #include "gettext.h"
 #include "config.h"
 #include "opts.h"
@@ -55,8 +54,6 @@ static struct argp_option options[] =
 static void 
 free_arguments ()
 {
-  free (arguments.fileschanged.exec_cmd);
-  free (arguments.fileschanged.filelist_filename);
   if (arguments.args)
     free (arguments.args);
 }
@@ -70,8 +67,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
   case 's':
       {
 	char *tmp;
-	for(tmp = strtok(arg, ","); tmp!=NULL;
-	    tmp=strtok(NULL,","))
+	for(tmp = strtok(arg, ","); tmp != NULL; tmp = strtok (NULL, ","))
 	  {
 	    if (strcasecmp (tmp, _("created")) == 0)
 	      parse_opt ('c', NULL, state);
@@ -82,7 +78,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
 	    else if (strcasecmp (tmp, _("executing")) == 0)
 	      parse_opt ('e', NULL, state);
 	    else if (strcasecmp (tmp, _("executed")) == 0)
-	      parse_opt ('e', NULL, state);
+	      parse_opt ('E', NULL, state);
 	    else if (strcasecmp (tmp, _("all")) == 0)
 	      parse_opt ('a', NULL, state);
 	    else
@@ -125,7 +121,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
   case 'l':
     arguments->fileschanged.filelist = 1;
     arguments->fileschanged.filestomonitor = 0;
-    arguments->fileschanged.filelist_filename = strdup (arg);
+    arguments->fileschanged.filelist_filename = arg;
     break;
   case 'p':
     arguments->fileschanged.showaction = 1;
@@ -136,21 +132,19 @@ parse_opt (int key, char *arg, struct argp_state *state)
       arguments->fileschanged.filechangetimeout = -1;
     break;
   case 'x':
-    if (arguments->fileschanged.exec_cmd)
-      free (arguments->fileschanged.exec_cmd);
-    arguments->fileschanged.exec_cmd = strdup (arg);
+    arguments->fileschanged.exec_cmd = arg;
     break;
   case 'L':
     arguments->fileschanged.dereference_symlinks = 1;
     break;
   case ARGP_KEY_INIT:
     free_arguments ();
-    arguments->args = (char**) malloc (1 * sizeof (char**));
+    arguments->args = (char **) malloc (1 * sizeof (char **));
     break;
   case ARGP_KEY_ARG:
     arguments->arraylen++; 
-    arguments->args = (char **)realloc (arguments->args, 
-				       arguments->arraylen * sizeof (char*));
+    arguments->args = (char **) realloc (arguments->args, 
+				       arguments->arraylen * sizeof (char *));
     arguments->args[state->arg_num] = arg;
     break;
   case ARGP_KEY_END:
@@ -165,10 +159,8 @@ static void
 set_default_arguments (struct fileschanged_arguments_t *fileschanged)
 {
   //set some default values if options not set
-  if ((fileschanged->showcreated == 0)  &&
-      (fileschanged->showchanged == 0)   &&
-      (fileschanged->showdeleted == 0)   &&
-      (fileschanged->showexecuting == 0) &&
+  if ((fileschanged->showcreated == 0) && (fileschanged->showchanged == 0) &&
+      (fileschanged->showdeleted == 0) && (fileschanged->showexecuting == 0) &&
       (fileschanged->showfinishedexecuting == 0))
     {
       fileschanged->showcreated = 1; // if not showing anything
@@ -178,8 +170,7 @@ set_default_arguments (struct fileschanged_arguments_t *fileschanged)
   if (fileschanged->filechangetimeout == 0)
     fileschanged->filechangetimeout = 2;
 
-  if ((fileschanged->filestomonitor == 0) && 
-      (fileschanged->filelist == 0))
+  if ((fileschanged->filestomonitor == 0) && (fileschanged->filelist == 0))
     fileschanged->filestomonitor = 1;
 
   if (fileschanged->filechangetimeout > 0)
@@ -206,4 +197,3 @@ parse_opts(int argc, char **argv, struct arguments_t *arguments)
   set_default_arguments (&arguments->fileschanged);
   return;
 }
-
