@@ -1,8 +1,5 @@
 #ifndef FILESCHANGED_OPTS_H
 #define FILESCHANGED_OPTS_H
-#ifdef __cplusplus
-extern "C" {
-#endif
 #define _(__str) gettext(__str)
 #define N_(__str) gettext_noop(__str)
 
@@ -22,15 +19,13 @@ struct fileschanged_arguments_t
 	char *exec_cmd;
 	int dereference_symlinks;
 };
-struct arguments_t {
+struct arguments_t 
+{
 	char **args;
 	int arraylen; //for argument processing
 	struct fileschanged_arguments_t fileschanged;
 };
 
-#ifdef __cplusplus
-}
-#endif
 void parse_opts(int argc, char **argv, struct arguments_t *arguments);
 
 #endif
